==> scorchful-0.15.8%2B1.21.1-sources.jar: com/github/thedeathlycow/scorchful/mixin/server/SandAccumulationServerWorldMixin.java <==
package com.github.thedeathlycow.scorchful.mixin.server;

import com.github.thedeathlycow.scorchful.server.SandAccumulation;
import org.spongepowered.asm.mixin.Mixin;
import org.spongepowered.asm.mixin.injection.At;
import org.spongepowered.asm.mixin.injection.Inject;
import org.spongepowered.asm.mixin.injection.callback.CallbackInfo;

import java.util.function.Supplier;
import net.minecraft.class_1937;
import net.minecraft.class_2818;
import net.minecraft.class_2874;
import net.minecraft.class_3218;
import net.minecraft.class_3695;
import net.minecraft.class_5269;
import net.minecraft.class_5321;
import net.minecraft.class_5455;
import net.minecraft.class_6880;

@Mixin(class_3218.class)
public abstract class SandAccumulationServerWorldMixin extends class_1937 {

    protected SandAccumulationServerWorldMixin(class_5269 properties, class_5321<class_1937> registryRef, class_5455 registryManager, class_6880<class_2874> dimensionEntry, Supplier<class_3695> profiler, boolean isClient, boolean debugWorld, long biomeAccess, int maxChainedNeighborUpdates) {
        super(properties, registryRef, registryManager, dimensionEntry, profiler, isClient, debugWorld, biomeAccess, maxChainedNeighborUpdates);
    }

    @Inject(
            method = "tickChunk",
            at = @At("TAIL")
    )
    private void doSandPileAccumulation(class_2818 chunk, int randomTickSpeed, CallbackInfo ci) {
        class_3695 profiler = this.method_16107();
        profiler.method_15396("scorchful_sandpiles");
        SandAccumulation.tickChunk((class_3218) (Object) this, chunk, randomTickSpeed);
        profiler.method_15407();
    }
}

==> scorchful-0.16.0%2B1.21.9-sources.jar: com/github/thedeathlycow/scorchful/mixin/server/SandAccumulationServerWorldMixin.java <==
package com.github.thedeathlycow.scorchful.mixin.server;

import com.github.thedeathlycow.scorchful.server.SandAccumulation;
import net.minecraft.class_10209;
import net.minecraft.class_1937;
import net.minecraft.class_2818;
import net.minecraft.class_2874;
import net.minecraft.class_3218;
import net.minecraft.class_3695;
import net.minecraft.class_5269;
import net.minecraft.class_5321;
import net.minecraft.class_5455;
import net.minecraft.class_6880;
import org.spongepowered.asm.mixin.Mixin;
import org.spongepowered.asm.mixin.injection.At;
import org.spongepowered.asm.mixin.injection.Inject;
import org.spongepowered.asm.mixin.injection.callback.CallbackInfo;

@Mixin(class_3218.class)
public abstract class SandAccumulationServerWorldMixin extends class_1937 {
    protected SandAccumulationServerWorldMixin(class_5269 properties, class_5321<class_1937> registryRef, class_5455 registryManager, class_6880<class_2874> dimensionEntry, boolean isClient, boolean debugWorld, long seed, int maxChainedNeighborUpdates) {
        super(properties, registryRef, registryManager, dimensionEntry, isClient, debugWorld, seed, maxChainedNeighborUpdates);
    }

    @Inject(
            method = "tickChunk",
            at = @At("TAIL")
    )
    private void doSandPileAccumulation(class_2818 chunk, int randomTickSpeed, CallbackInfo ci) {
        class_3695 profiler = class_10209.method_64146();
        profiler.method_15396("scorchful_sandpiles");
        SandAccumulation.tickChunk((class_3218) (Object) this, chunk, randomTickSpeed);
        profiler.method_15407();
    }
}
